#
# spec file for package qt6-sensors
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define real_version 6.4.2
%define short_version 6.4
%define short_name qtsensors
%define tar_name qtsensors-everywhere-src
%define tar_suffix %{nil}
#
%global qt6_flavor %{nil}
%if "%{qt6_flavor}" == "docs"
%define pkg_suffix -docs
%endif
#
Name:           qt6-sensors%{?pkg_suffix}
Version:        6.4.2
Release:        bp155.1.20
Summary:        Qt Sensors API to access sensor hardware
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
URL:            https://www.qt.io
Source:         https://download.qt.io/official_releases/qt/%{short_version}/%{real_version}%{tar_suffix}/submodules/%{tar_name}-%{real_version}%{tar_suffix}.tar.xz
Source99:       qt6-sensors-rpmlintrc
BuildRequires:  pkgconfig
BuildRequires:  qt6-core-private-devel
BuildRequires:  cmake(Qt6Core)
BuildRequires:  cmake(Qt6DBus)
BuildRequires:  cmake(Qt6Gui)
BuildRequires:  cmake(Qt6Multimedia)
BuildRequires:  cmake(Qt6Qml)
BuildRequires:  cmake(Qt6Quick)
BuildRequires:  cmake(Qt6Svg)
BuildRequires:  cmake(Qt6Widgets)
BuildRequires:  cmake(Qt6Xml)
%if "%{qt6_flavor}" == "docs"
BuildRequires:  qt6-tools
%{qt6_doc_packages}
%else
# boo#1188098
Requires:       (iio-sensor-proxy if systemd)
%endif

%description
The Qt Sensors API provides access to sensor hardware via QML and C++
interfaces. The Qt Sensors API also provides a motion gesture recognition API
for devices.

%if !%{qt6_docs_flavor}

%package imports
Summary:        Qt 6 Sensors QML files and plugins

%description imports
QML files and plugins from the Qt 6 Sensors module

%package -n libQt6Sensors6
Summary:        Qt 6 Sensors library

%description -n libQt6Sensors6
The Qt 6 Sensors library.

%package devel
Summary:        Qt 6 Sensors library - Development files
Requires:       libQt6Sensors6 = %{version}
Requires:       cmake(Qt6Core)

%description devel
Development files for the Qt 6 Sensors library.

%package private-devel
Summary:        Non-ABI stable API for the Qt 6 Sensors library
Requires:       cmake(Qt6Sensors) = %{real_version}
%requires_eq    qt6-qml-private-devel

%description private-devel
This package provides private headers of libQt6Sensors that do not have any
ABI or API guarantees.

%package -n libQt6SensorsQuick6
Summary:        Qt 6 SensorsQuick library

%description -n libQt6SensorsQuick6
The Qt6 SensorsQuick library.

%package -n qt6-sensorsquick-devel
Summary:        Qt 6 SensorsQuick library - Development files
Requires:       libQt6SensorsQuick6 = %{version}
Requires:       cmake(Qt6Qml)
Requires:       cmake(Qt6Sensors) = %{real_version}

%description -n qt6-sensorsquick-devel
Development files for the Qt 6 SensorsQuick library.

%package -n qt6-sensorsquick-private-devel
Summary:        Non-ABI stable API for the Qt 6 SensorsQuick library
Requires:       cmake(Qt6SensorsQuick) = %{real_version}

%description -n qt6-sensorsquick-private-devel
This package provides private headers of libQt6SensorsQuick that do not have any
ABI or API guarantees.

%{qt6_examples_package}

%endif

%prep
%autosetup -p1 -n %{tar_name}-%{real_version}%{tar_suffix}

%build
%cmake_qt6

%{qt6_build}

%install
%{qt6_install}

%if !%{qt6_docs_flavor}

# CMake files are not needed for plugins
rm -r %{buildroot}%{_qt6_cmakedir}/Qt6Qml/QmlPlugins
rm %{buildroot}%{_qt6_cmakedir}/*/*Plugin{Config,ConfigVersion,Targets*}.cmake

%post -n libQt6Sensors6 -p /sbin/ldconfig
%post -n libQt6SensorsQuick6 -p /sbin/ldconfig
%postun -n libQt6Sensors6 -p /sbin/ldconfig
%postun -n libQt6SensorsQuick6 -p /sbin/ldconfig

%files
%{_qt6_pluginsdir}/sensors/

%files imports
%{_qt6_qmldir}/QtSensors/

%files -n libQt6Sensors6
%license LICENSES/*
%{_qt6_libdir}/libQt6Sensors.so.*

%files devel
%{_qt6_cmakedir}/Qt6/FindSensorfw.cmake
%{_qt6_cmakedir}/Qt6BuildInternals/StandaloneTests/QtSensorsTestsConfig.cmake
%{_qt6_cmakedir}/Qt6Sensors/
%{_qt6_descriptionsdir}/Sensors.json
%{_qt6_includedir}/QtSensors/
%{_qt6_libdir}/libQt6Sensors.prl
%{_qt6_libdir}/libQt6Sensors.so
%{_qt6_metatypesdir}/qt6sensors_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_sensors.pri
%{_qt6_pkgconfigdir}/Qt6Sensors.pc
%exclude %{_qt6_includedir}/QtSensors/%{real_version}

%files private-devel
%{_qt6_includedir}/QtSensors/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_sensors_private.pri

%files -n libQt6SensorsQuick6
%{_qt6_libdir}/libQt6SensorsQuick.so.*

%files -n qt6-sensorsquick-devel
%{_qt6_cmakedir}/Qt6SensorsQuick/
%{_qt6_descriptionsdir}/SensorsQuick.json
%{_qt6_includedir}/QtSensorsQuick/
%{_qt6_libdir}/libQt6SensorsQuick.prl
%{_qt6_libdir}/libQt6SensorsQuick.so
%{_qt6_metatypesdir}/qt6sensorsquick_*_metatypes.json
%{_qt6_mkspecsdir}/modules/qt_lib_sensorsquick.pri
%{_qt6_pkgconfigdir}/Qt6SensorsQuick.pc
%exclude %{_qt6_includedir}/QtSensorsQuick/%{real_version}

%files -n qt6-sensorsquick-private-devel
%{_qt6_includedir}/QtSensorsQuick/%{real_version}/
%{_qt6_mkspecsdir}/modules/qt_lib_sensorsquick_private.pri

%endif

%changelog
* Fri Jan  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 6.4.2:
  * https://www.qt.io/blog/qt-6.4.2-released
* Tue Nov 15 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.1:
  * https://www.qt.io/blog/qt-6.4.1-released
* Thu Sep 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0:
  * https://www.qt.io/blog/qt-6.4-released
* Fri Sep 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.4.0 RC
* Fri Sep  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.2:
  * https://www.qt.io/blog/qt-6.3.2-released
* Fri Jun 17 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.1:
  * https://www.qt.io/blog/qt-6.3.1-released
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0:
  * https://www.qt.io/blog/qt-6.3-released
* Tue Mar 29 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.3.0-rc
* Mon Mar 21 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.4
  * https://www.qt.io/blog/qt-6.2.4-released
* Mon Jan 31 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.3:
  * https://www.qt.io/blog/qt-6.2.3-released
* Wed Dec  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.2
  * https://www.qt.io/blog/qt-6.2.2-released
- Make sure all dependencies are present when installing devel
  packages. Qt >= 6.2.2 is much less permissive.
* Tue Oct 26 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.1
  * https://www.qt.io/blog/qt-6.2.1-released
* Thu Sep 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0:
  * https://www.qt.io/blog/qt-6.2-lts-released
* Sat Sep 25 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc2
* Thu Sep 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-rc
* Thu Sep  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 6.2.0-beta4
* Wed Jun 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Init qt6-sensors.
